==> neo4j-cypher-compiler-2.2-2.2.5-sources.jar: org/neo4j/cypher/internal/compiler/v2_2/pipes/LazyTypes.scala <==
/*
 * Copyright (c) 2002-2015 "Neo Technology,"
 * Network Engine for Objects in Lund AB [http://neotechnology.com]
 *
 * This file is part of Neo4j.
 *
 * Neo4j is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.neo4j.cypher.internal.compiler.v2_2.pipes

import org.neo4j.cypher.internal.compiler.v2_2.ast.RelTypeName
import org.neo4j.cypher.internal.compiler.v2_2.planner.SemanticTable
import org.neo4j.cypher.internal.compiler.v2_2.spi.QueryContext

case class LazyTypes(names:Seq[String]) {
  private var ids = Seq.empty[Int]

  def types(context: QueryContext): Option[Seq[Int]] = names match {
      case Seq() => None
      case _     => {
        if (ids.size != names.size) {
          ids = names.flatMap(context.getOptRelTypeId)
        }
        Some(ids)
      }
    }
}

object LazyTypes {
  def apply(names: Seq[RelTypeName])(implicit table:SemanticTable): LazyTypes = {
    val types = LazyTypes(names.map(_.name))
    types.ids = names.flatMap(_.id).map(_.id)
    types
  }
  val empty = LazyTypes(Seq.empty[String])
}

==> neo4j-cypher-compiler-2.3-2.3.1-sources.jar: org/neo4j/cypher/internal/compiler/v2_3/pipes/LazyTypes.scala <==
/*
 * Copyright (c) 2002-2015 "Neo Technology,"
 * Network Engine for Objects in Lund AB [http://neotechnology.com]
 *
 * This file is part of Neo4j.
 *
 * Neo4j is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.neo4j.cypher.internal.compiler.v2_3.pipes

import org.neo4j.cypher.internal.frontend.v2_3.ast.RelTypeName
import org.neo4j.cypher.internal.compiler.v2_3.spi.QueryContext
import org.neo4j.cypher.internal.frontend.v2_3.SemanticTable

case class LazyTypes(names:Seq[String]) {
  private var ids = Seq.empty[Int]

  def types(context: QueryContext): Option[Seq[Int]] = names match {
      case Seq() => None
      case _     => {
        if (ids.size != names.size) {
          ids = names.flatMap(context.getOptRelTypeId)
        }
        Some(ids)
      }
    }
}

object LazyTypes {
  def apply(names: Seq[RelTypeName])(implicit table:SemanticTable): LazyTypes = {
    val types = LazyTypes(names.map(_.name))
    types.ids = names.flatMap(_.id).map(_.id)
    types
  }
  val empty = LazyTypes(Seq.empty[String])
}
